// Modify the displayed message to clarify where safelinks are
// inserted and to show the actual link targets.

const safelinksRegexp = new RegExp(
    'https?://[^.]+[.]safelinks[.]protection[.]outlook[.]com/[?]url=([^&]+)&.*',
    'gi'
);

function getTextNodes(elem) {
    var result = [];
    if (elem) {
	for (var nodes = elem.childNodes, i = nodes.length; i--;) {
	    let node = nodes[i];
	    let nodeType = node.nodeType;
	    
	    if (nodeType == Node.TEXT_NODE) {
		result.push(node);
	    }
	    else if (nodeType == Node.ELEMENT_NODE
		     || nodeType == Node.DOCUMENT_NODE
		     || nodeType == Node.DOCUMENT_FRAGMENT_NODE) {
		result = result.concat(getTextNodes(node));
	    }
	}
    }
    return result;
}

for (const link of document.links) {
    let display = link.innerHTML;

    // Mangle the link text
    for (const node of getTextNodes(link)) {
	node.textContent = node.textContent.replaceAll(
	    safelinksRegexp, (match, url) => {
		try {
		    return decodeURIComponent(url);
		}
		catch (e) {
		    return url;
		}
	    });	
    }

    // Generate the tooltip and set link class
    for (const match of link.href.matchAll(safelinksRegexp)) {
	link.classList.add('liu_safelinks_link');

	let tooltiptext = match[1];
	let tooltip = document.createElement('span');
	tooltip.classList.add('liu_safelinks_tooltip');
	try {
	    tooltiptext = decodeURIComponent(tooltiptext);
	}
	catch (e) {
	}
	tooltip.textContent = tooltiptext;
	link.appendChild(tooltip);
	break;
    }
}
